@@ -15,4 +15,4 @@ def GetAnime(search: str, baseUrl: str) -> AniListAnime:
     try:
         return ani_list_anime_from_dict(r)
     except json.JSONDecodeError:
-        raise AniListException("{]".format(ani_list_error_from_dict(r)))
+        raise AniListException("{}".format(ani_list_error_from_dict(r)))
